/// <reference types="node" />
import { RippleAPI } from 'ripple-lib';
import BigNumber from 'bignumber.js';
import StoreWrapper from './store-wrapper';
import { Claim, Paychan } from './util';
export interface AccountParams {
    account: string;
    store: StoreWrapper;
    api: RippleAPI;
    currencyScale: number;
    log: any;
}
export declare enum ReadyState {
    INITIAL = 0,
    LOADING_CHANNEL = 1,
    ESTABLISHING_CHANNEL = 2,
    PREPARING_CHANNEL = 3,
    LOADING_CLIENT_CHANNEL = 4,
    ESTABLISHING_CLIENT_CHANNEL = 5,
    PREPARING_CLIENT_CHANNEL = 6,
    READY = 7,
    BLOCKED = 8
}
export declare class Account {
    private _store;
    private _account;
    private _api;
    private _currencyScale;
    private _paychan?;
    private _clientPaychan?;
    private _clientChannel?;
    private _funding;
    private _claimIntervalId?;
    private _log;
    private _state;
    constructor(opts: AccountParams);
    xrpToBase(amount: BigNumber.Value): string;
    getAccount(): string;
    getPaychan(): any;
    getClientPaychan(): Paychan | void;
    setClaimIntervalId(claimIntervalId: NodeJS.Timer): void;
    getClaimIntervalId(): NodeJS.Timer | void;
    getLastClaimedAmount(): string;
    setLastClaimedAmount(amount: string): void;
    isFunding(): boolean;
    setFunding(funding: boolean): void;
    connect(): Promise<void>;
    _connectChannel(): Promise<void>;
    _connectClientChannel(): Promise<void>;
    disconnect(): void;
    getBalance(): BigNumber;
    getIncomingClaim(): Claim;
    getChannel(): string;
    isBlocked(): boolean;
    getBlockReason(): string | false;
    getClientChannel(): string;
    getOwedBalance(): BigNumber;
    setOwedBalance(balance: string): void;
    getOutgoingBalance(): BigNumber;
    setBalance(balance: string): void;
    setIncomingClaim(incomingClaim: Claim): void;
    prepareChannel(): void;
    resetChannel(): void;
    setChannel(channel: string, paychan: Paychan): Promise<void>;
    reloadChannel(channel: string, paychan: Paychan): void;
    deleteChannel(): void;
    block(isBlocked?: boolean, reason?: string): void;
    prepareClientChannel(): void;
    resetClientChannel(): void;
    setClientChannel(clientChannel: string, clientPaychan: Paychan): void;
    reloadClientChannel(clientChannel: string, clientPaychan: Paychan): void;
    setOutgoingBalance(outgoingBalance: string): void;
    isReady(): boolean;
    getState(): ReadyState;
    getStateString(): string;
    private _assertState;
}
