/// <reference types="node" />
import * as IlpPacket from 'ilp-packet';
import BigNumber from 'bignumber.js';
import { Account } from './account';
import { Protocol, BtpData, Claim, Paychan, Store } from './util';
declare const MiniAccountsPlugin: any;
export interface ExtraInfo {
    address: string;
    account: string;
    currencyScale: number;
    channel?: string;
    clientChannel?: string;
}
export declare enum AdminCommandName {
    BLOCK = "block",
    SETTLE = "settle"
}
export interface AdminCommand {
    command: AdminCommandName;
    account: string;
    amount?: string;
}
export interface IlpPluginAsymServerOpts {
    assetScale?: number;
    currencyScale?: number;
    maxPacketAmount?: string;
    xrpServer: string;
    secret: string;
    address: string;
    maxBalance?: string;
    bandwidth?: string;
    claimInterval?: number;
    outgoingChannelAmount?: number;
    minIncomingChannelAmount?: number;
    _store: Store;
    maxFeePercent?: string;
    log: any;
}
export default class IlpPluginAsymServer extends MiniAccountsPlugin {
    static version: number;
    private _maxPacketAmount;
    private _currencyScale;
    private _xrpServer;
    private _secret;
    private _address;
    private _api;
    private _watcher;
    private _bandwidth;
    private _claimInterval;
    private _outgoingChannelAmount;
    private _minIncomingChannelAmount;
    private _store;
    private _txSubmitter;
    private _maxFeePercent;
    private _channelToAccount;
    private _accounts;
    private _log;
    constructor(opts: IlpPluginAsymServerOpts);
    xrpToBase(amount: BigNumber.Value): string;
    baseToXrp(amount: BigNumber.Value): string;
    sendTransfer(): void;
    _validatePaychanDetails(paychan: Paychan): void;
    _getAccount(from: string): Account;
    _extraInfo(account: Account): ExtraInfo;
    _channelClaim(account: Account, close?: boolean): Promise<void>;
    _channelClose(channelId: string): Promise<void>;
    _preConnect(): Promise<void>;
    _connect(address: string, btpData: BtpData): Promise<null>;
    _fundOutgoingChannel(account: Account, primary: Protocol): Promise<string>;
    _handleCustomData(from: string, message: BtpData): Promise<any>;
    _isClaimProfitable(account: Account): Promise<boolean>;
    _autoClaim(account: Account): Promise<void>;
    _registerAutoClaim(account: Account): Promise<void>;
    _handleIncomingPrepare(account: Account, ilpData: Buffer): void;
    _rejectIncomingTransfer(account: Account, ilpData: Buffer): void;
    _sendPrepare(destination: string, parsedPacket: IlpPacket.IlpPacket): void;
    _handlePrepareResponse(destination: string, parsedResponse: IlpPacket.IlpPacket, preparePacket: {
        type: IlpPacket.Type.TYPE_ILP_PREPARE;
        typeString?: IlpPacket.Type.TYPE_ILP_PREPARE;
        data: IlpPacket.IlpPrepare;
    }): void;
    _getAmountOwed(to: string): BigNumber;
    _increaseAmountOwed(amount: string, to: string): void;
    _decreaseAmountOwed(amount: string, to: string): void;
    sendMoney(): Promise<void>;
    _sendMoneyToAccount(transferAmount: string, to: string): {
        protocolName: string;
        contentType: number;
        data: Buffer;
    }[];
    _handleClaim(account: Account, claim: Claim): void;
    _handleMoney(from: string, btpData: BtpData): void;
    _disconnect(): Promise<void>;
    getAdminInfo(): Promise<{
        xrpAddress: string;
        xrpBalance: {
            total: string;
            reserved: string;
            available: string;
        };
        clients: ({
            account: string;
            xrpAddress: any;
            channel: string;
            channelBalance: any;
            clientChannel: string;
            clientChannelBalance: string;
            state: string;
        } | null)[];
    }>;
    sendAdminInfo(cmd: AdminCommand): Promise<{}>;
}
export {};
